==> haskell-barbies-2.0.3.1-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-barbies.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 barbies
version:              2.0.3.1
visibility:           public
id:                   barbies-2.0.3.1-B6Q1jG0YjDb1Yg6rEK76Py
key:                  barbies-2.0.3.1-B6Q1jG0YjDb1Yg6rEK76Py
license:              BSD-3-Clause
copyright:            2018 Daniel Gorin
maintainer:           jcpetruzza@gmail.com
author:               Daniel Gorin
homepage:             https://github.com/jcpetruzza/barbies#readme
synopsis:             Classes for working with types that can change clothes.
description:
    Types that are parametric on a functor are like Barbies that have an outfit for each role. This package provides the basic abstractions to work with them comfortably.

category:             Data Structures
abi:                  6ce62f82ee3e10d4ead67eeeed644186
exposed:              True
exposed-modules:
    Barbies Barbies.Bare Barbies.Bi Barbies.Constraints
    Barbies.Internal Data.Barbie Data.Barbie.Bare
    Data.Barbie.Constraints Data.Functor.Barbie Data.Functor.Prod
    Data.Functor.Transformer

hidden-modules:
    Barbies.Generics.Applicative Barbies.Generics.Bare
    Barbies.Generics.Constraints Barbies.Generics.Distributive
    Barbies.Generics.Functor Barbies.Generics.Traversable
    Barbies.Internal.ApplicativeB Barbies.Internal.ApplicativeT
    Barbies.Internal.BareB Barbies.Internal.ConstraintsB
    Barbies.Internal.ConstraintsT Barbies.Internal.Containers
    Barbies.Internal.Dicts Barbies.Internal.DistributiveB
    Barbies.Internal.DistributiveT Barbies.Internal.FunctorB
    Barbies.Internal.FunctorT Barbies.Internal.MonadT
    Barbies.Internal.TraversableB Barbies.Internal.TraversableT
    Barbies.Internal.Trivial Barbies.Internal.Wear
    Barbies.Internal.Wrappers Barbies.Internal.Writer
    Data.Generics.GenericN Data.Barbie.Internal.Product
    Data.Barbie.Internal.ProductC

import-dirs:          /usr/lib/ghc-9.0.2/site-local/barbies-2.0.3.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/barbies-2.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-barbies
hs-libraries:         HSbarbies-2.0.3.1-B6Q1jG0YjDb1Yg6rEK76Py
depends:
    base-4.15.1.0 distributive-0.6.2.1-9wcbdvxUhl373VFDpLmb6H
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-barbies/html/barbies.haddock
haddock-html:         /usr/share/doc/haskell-barbies/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-barbies-2.0.4.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-barbies.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 barbies
version:              2.0.4.0
visibility:           public
id:                   barbies-2.0.4.0-DOGd3PaaVkV2CtJjR62DKU
key:                  barbies-2.0.4.0-DOGd3PaaVkV2CtJjR62DKU
license:              BSD-3-Clause
copyright:            2018 Daniel Gorin
maintainer:           jcpetruzza@gmail.com
author:               Daniel Gorin
homepage:             https://github.com/jcpetruzza/barbies#readme
synopsis:             Classes for working with types that can change clothes.
description:
    Types that are parametric on a functor are like Barbies that have an outfit for each role. This package provides the basic abstractions to work with them comfortably.

category:             Data Structures
abi:                  4057cdca1669e37356157a2676f51223
exposed:              True
exposed-modules:
    Barbies Barbies.Bare Barbies.Bi Barbies.Constraints
    Barbies.Internal Data.Barbie Data.Barbie.Bare
    Data.Barbie.Constraints Data.Functor.Barbie Data.Functor.Prod
    Data.Functor.Transformer

hidden-modules:
    Barbies.Generics.Applicative Barbies.Generics.Bare
    Barbies.Generics.Constraints Barbies.Generics.Distributive
    Barbies.Generics.Functor Barbies.Generics.Traversable
    Barbies.Internal.ApplicativeB Barbies.Internal.ApplicativeT
    Barbies.Internal.BareB Barbies.Internal.ConstraintsB
    Barbies.Internal.ConstraintsT Barbies.Internal.Containers
    Barbies.Internal.Dicts Barbies.Internal.DistributiveB
    Barbies.Internal.DistributiveT Barbies.Internal.FunctorB
    Barbies.Internal.FunctorT Barbies.Internal.MonadT
    Barbies.Internal.TraversableB Barbies.Internal.TraversableT
    Barbies.Internal.Trivial Barbies.Internal.Wear
    Barbies.Internal.Wrappers Barbies.Internal.Writer
    Data.Generics.GenericN Data.Barbie.Internal.Product
    Data.Barbie.Internal.ProductC

import-dirs:          /usr/lib/ghc-9.0.2/site-local/barbies-2.0.4.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/barbies-2.0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-barbies
hs-libraries:         HSbarbies-2.0.4.0-DOGd3PaaVkV2CtJjR62DKU
depends:
    base-4.15.1.0 distributive-0.6.2.1-CHPhCM075vGDbf02dWFJGH
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-barbies/html/barbies.haddock
haddock-html:         /usr/share/doc/haskell-barbies/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
